@@ -9,8 +9,8 @@
 # Copyright ©2011-2025. Hunan xxxxxxx Company limited. All rights reserved.
 # ---------------------------------------------------------------------------------------------------------
 """
-from typing import Optional
 import redis.asyncio as redis
+from typing import Optional, List, Union, Set
 
 """
 无重复
@@ -94,6 +94,44 @@ class AsyncReliableQueue:
         await pipe.execute()
         return len(tasks)
 
+    async def get_all_pending(self, count: int = 0) -> List[str]:
+        """
+        获取所有待执行任务
+         Args:
+        count: 若 > 0，使用 SSCAN 分批获取（避免大集合阻塞 Redis）；
+               若 = 0，使用 SMEMBERS 一次性获取（适用于小集合）。
+        """
+        members: Set[Union[str, bytes]] = set()
+        if count > 0:
+            cursor = 0
+            while True:
+                cursor, data = await self.redis.sscan(self.pending, cursor=cursor, count=count)
+                members.update(data)
+                if cursor == 0:
+                    break
+        else:
+            members = await self.redis.smembers(self.pending)
+        return list(members)
+
+    async def get_all_processing(self, count: int = 0) -> List[str]:
+        """
+        获取所有正在处理的任务
+         Args:
+        count: 若 > 0，使用 SSCAN 分批获取（避免大集合阻塞 Redis）；
+               若 = 0，使用 SMEMBERS 一次性获取（适用于小集合）。
+        """
+        members: Set[Union[str, bytes]] = set()
+        if count > 0:
+            cursor = 0
+            while True:
+                cursor, data = await self.redis.sscan(self.processing, cursor=cursor, count=count)
+                members.update(data)
+                if cursor == 0:
+                    break
+        else:
+            members = await self.redis.smembers(self.processing)
+        return list(members)
+
     # ================= 存在性判断 =================
     async def in_pending(self, task: str) -> bool:
         """是否在待执行队列"""
